==> haskell-dav-1.3.1-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.1
id: DAV-1.3.1-A5jgwskzXQVIpQam01bPc0
key: DAV-1.3.1-A5jgwskzXQVIpQam01bPc0
license: GPL-3
copyright: Copyright (C) 2012-2016  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: c7a056647a6e1ace46c796fee693be74
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/DAV-1.3.1
hs-libraries: HSDAV-1.3.1-A5jgwskzXQVIpQam01bPc0
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.4-HBBQ11vQccaG7MFhX9DRCl
    http-client-tls-0.3.3-1zlq0NC8UQhCr5x472wi20
    http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
    lens-4.15.1-DZbFGf4RlcKEQE2VkLJobh mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    xml-conduit-1.4.0.2-FtEadDL4T8uH2fh40slaBV
    xml-hamlet-0.4.0.12-AsCS9TTP8JnJk8rW8rpelE
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.1-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.1
id: DAV-1.3.1-9w6Vu7PgKhmI3uP01FXyoW
key: DAV-1.3.1-9w6Vu7PgKhmI3uP01FXyoW
license: GPL-3
copyright: Copyright (C) 2012-2016  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: a4b077e38e3e1d71aa4e8003264d39a6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/DAV-1.3.1
hs-libraries: HSDAV-1.3.1-9w6Vu7PgKhmI3uP01FXyoW
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.5-BYijqaHDvVGLG7BD5RqyBP
    http-client-tls-0.3.3-PtmOIlwb73GB1lVNYox3x
    http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
    lens-4.15.1-DP6vBRg4FH1sBGNXl8TVu mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    xml-conduit-1.4.0.2-7vb4Bw2Z28qIrjuvfmrYGe
    xml-hamlet-0.4.0.12-58GaEtowPJ22mIRfUi3qTY
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
